@@ -36,6 +36,7 @@ from .type_defs import (
     AnomalyMonitorTypeDef,
     AnomalySubscriptionTypeDef,
     CostCategoryRuleTypeDef,
+    CostCategorySplitChargeRuleTypeDef,
     CreateAnomalyMonitorResponseTypeDef,
     CreateAnomalySubscriptionResponseTypeDef,
     CreateCostCategoryDefinitionResponseTypeDef,
@@ -107,7 +108,7 @@ class Exceptions:
 
 class CostExplorerClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/ce.html#CostExplorer.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/ce.html#CostExplorer.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html)
     """
 
@@ -123,7 +124,7 @@ class CostExplorerClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/ce.html#CostExplorer.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/ce.html#CostExplorer.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#can_paginate)
         """
 
@@ -134,7 +135,7 @@ class CostExplorerClient(BaseClient):
         Creates a new cost anomaly detection monitor with the requested type and monitor
         specification.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/ce.html#CostExplorer.Client.create_anomaly_monitor)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/ce.html#CostExplorer.Client.create_anomaly_monitor)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#create_anomaly_monitor)
         """
 
@@ -144,7 +145,7 @@ class CostExplorerClient(BaseClient):
         """
         Adds a subscription to a cost anomaly detection monitor.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/ce.html#CostExplorer.Client.create_anomaly_subscription)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/ce.html#CostExplorer.Client.create_anomaly_subscription)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#create_anomaly_subscription)
         """
 
@@ -154,12 +155,13 @@ class CostExplorerClient(BaseClient):
         Name: str,
         RuleVersion: Literal["CostCategoryExpression.v1"],
         Rules: List["CostCategoryRuleTypeDef"],
-        DefaultValue: str = None
+        DefaultValue: str = None,
+        SplitChargeRules: List["CostCategorySplitChargeRuleTypeDef"] = None
     ) -> CreateCostCategoryDefinitionResponseTypeDef:
         """
         Creates a new Cost Category with the requested name and rules.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/ce.html#CostExplorer.Client.create_cost_category_definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/ce.html#CostExplorer.Client.create_cost_category_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#create_cost_category_definition)
         """
 
@@ -167,7 +169,7 @@ class CostExplorerClient(BaseClient):
         """
         Deletes a cost anomaly monitor.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/ce.html#CostExplorer.Client.delete_anomaly_monitor)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/ce.html#CostExplorer.Client.delete_anomaly_monitor)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#delete_anomaly_monitor)
         """
 
@@ -175,7 +177,7 @@ class CostExplorerClient(BaseClient):
         """
         Deletes a cost anomaly subscription.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/ce.html#CostExplorer.Client.delete_anomaly_subscription)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/ce.html#CostExplorer.Client.delete_anomaly_subscription)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#delete_anomaly_subscription)
         """
 
@@ -185,7 +187,7 @@ class CostExplorerClient(BaseClient):
         """
         Deletes a Cost Category.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/ce.html#CostExplorer.Client.delete_cost_category_definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/ce.html#CostExplorer.Client.delete_cost_category_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#delete_cost_category_definition)
         """
 
@@ -196,7 +198,7 @@ class CostExplorerClient(BaseClient):
         Returns the name, ARN, rules, definition, and effective dates of a Cost Category
         that's defined in the account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/ce.html#CostExplorer.Client.describe_cost_category_definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/ce.html#CostExplorer.Client.describe_cost_category_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#describe_cost_category_definition)
         """
 
@@ -210,7 +212,7 @@ class CostExplorerClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/ce.html#CostExplorer.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/ce.html#CostExplorer.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#generate_presigned_url)
         """
 
@@ -225,10 +227,10 @@ class CostExplorerClient(BaseClient):
         MaxResults: int = None
     ) -> GetAnomaliesResponseTypeDef:
         """
-        Retrieves all of the cost anomalies detected on your account, during the time
-        period specified by the `DateInterval` object.
+        Retrieves all of the cost anomalies detected on your account during the time
+        period that's specified by the `DateInterval` object.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/ce.html#CostExplorer.Client.get_anomalies)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/ce.html#CostExplorer.Client.get_anomalies)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_anomalies)
         """
 
@@ -238,7 +240,7 @@ class CostExplorerClient(BaseClient):
         """
         Retrieves the cost anomaly monitor definitions for your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/ce.html#CostExplorer.Client.get_anomaly_monitors)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/ce.html#CostExplorer.Client.get_anomaly_monitors)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_anomaly_monitors)
         """
 
@@ -253,7 +255,7 @@ class CostExplorerClient(BaseClient):
         """
         Retrieves the cost anomaly subscription objects for your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/ce.html#CostExplorer.Client.get_anomaly_subscriptions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/ce.html#CostExplorer.Client.get_anomaly_subscriptions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_anomaly_subscriptions)
         """
 
@@ -270,7 +272,7 @@ class CostExplorerClient(BaseClient):
         """
         Retrieves cost and usage metrics for your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/ce.html#CostExplorer.Client.get_cost_and_usage)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/ce.html#CostExplorer.Client.get_cost_and_usage)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_cost_and_usage)
         """
 
@@ -287,7 +289,7 @@ class CostExplorerClient(BaseClient):
         """
         Retrieves cost and usage metrics with resources for your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/ce.html#CostExplorer.Client.get_cost_and_usage_with_resources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/ce.html#CostExplorer.Client.get_cost_and_usage_with_resources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_cost_and_usage_with_resources)
         """
 
@@ -305,7 +307,7 @@ class CostExplorerClient(BaseClient):
         """
         Retrieves an array of Cost Category names and values incurred cost.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/ce.html#CostExplorer.Client.get_cost_categories)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/ce.html#CostExplorer.Client.get_cost_categories)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_cost_categories)
         """
 
@@ -322,7 +324,7 @@ class CostExplorerClient(BaseClient):
         Retrieves a forecast for how much Amazon Web Services predicts that you will
         spend over the forecast time period that you select, based on your past costs.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/ce.html#CostExplorer.Client.get_cost_forecast)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/ce.html#CostExplorer.Client.get_cost_forecast)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_cost_forecast)
         """
 
@@ -342,7 +344,7 @@ class CostExplorerClient(BaseClient):
         Retrieves all available filter values for a specified filter over a period of
         time.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/ce.html#CostExplorer.Client.get_dimension_values)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/ce.html#CostExplorer.Client.get_dimension_values)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_dimension_values)
         """
 
@@ -361,7 +363,7 @@ class CostExplorerClient(BaseClient):
         """
         Retrieves the reservation coverage for your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/ce.html#CostExplorer.Client.get_reservation_coverage)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/ce.html#CostExplorer.Client.get_reservation_coverage)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_reservation_coverage)
         """
 
@@ -382,7 +384,7 @@ class CostExplorerClient(BaseClient):
         """
         Gets recommendations for which reservations to purchase.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/ce.html#CostExplorer.Client.get_reservation_purchase_recommendation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/ce.html#CostExplorer.Client.get_reservation_purchase_recommendation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_reservation_purchase_recommendation)
         """
 
@@ -400,7 +402,7 @@ class CostExplorerClient(BaseClient):
         """
         Retrieves the reservation utilization for your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/ce.html#CostExplorer.Client.get_reservation_utilization)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/ce.html#CostExplorer.Client.get_reservation_utilization)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_reservation_utilization)
         """
 
@@ -417,7 +419,7 @@ class CostExplorerClient(BaseClient):
         Creates recommendations that help you save cost by identifying idle and
         underutilized Amazon EC2 instances.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/ce.html#CostExplorer.Client.get_rightsizing_recommendation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/ce.html#CostExplorer.Client.get_rightsizing_recommendation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_rightsizing_recommendation)
         """
 
@@ -436,7 +438,7 @@ class CostExplorerClient(BaseClient):
         """
         Retrieves the Savings Plans covered for your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/ce.html#CostExplorer.Client.get_savings_plans_coverage)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/ce.html#CostExplorer.Client.get_savings_plans_coverage)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_savings_plans_coverage)
         """
 
@@ -456,7 +458,7 @@ class CostExplorerClient(BaseClient):
         Retrieves your request parameters, Savings Plan Recommendations Summary and
         Details.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/ce.html#CostExplorer.Client.get_savings_plans_purchase_recommendation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/ce.html#CostExplorer.Client.get_savings_plans_purchase_recommendation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_savings_plans_purchase_recommendation)
         """
 
@@ -472,7 +474,7 @@ class CostExplorerClient(BaseClient):
         Retrieves the Savings Plans utilization for your account across date ranges with
         daily or monthly granularity.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/ce.html#CostExplorer.Client.get_savings_plans_utilization)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/ce.html#CostExplorer.Client.get_savings_plans_utilization)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_savings_plans_utilization)
         """
 
@@ -490,7 +492,7 @@ class CostExplorerClient(BaseClient):
         Retrieves attribute data along with aggregate utilization and savings data for a
         given time period.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/ce.html#CostExplorer.Client.get_savings_plans_utilization_details)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/ce.html#CostExplorer.Client.get_savings_plans_utilization_details)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_savings_plans_utilization_details)
         """
 
@@ -508,7 +510,7 @@ class CostExplorerClient(BaseClient):
         """
         Queries for available tag keys and tag values for a specified period.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/ce.html#CostExplorer.Client.get_tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/ce.html#CostExplorer.Client.get_tags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_tags)
         """
 
@@ -525,7 +527,7 @@ class CostExplorerClient(BaseClient):
         Retrieves a forecast for how much Amazon Web Services predicts that you will use
         over the forecast time period that you select, based on your past usage.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/ce.html#CostExplorer.Client.get_usage_forecast)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/ce.html#CostExplorer.Client.get_usage_forecast)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get_usage_forecast)
         """
 
@@ -536,7 +538,7 @@ class CostExplorerClient(BaseClient):
         Returns the name, ARN, `NumberOfRules` and effective dates of all Cost
         Categories defined in the account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/ce.html#CostExplorer.Client.list_cost_category_definitions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/ce.html#CostExplorer.Client.list_cost_category_definitions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#list_cost_category_definitions)
         """
 
@@ -546,7 +548,7 @@ class CostExplorerClient(BaseClient):
         """
         Modifies the feedback property of a given cost anomaly.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/ce.html#CostExplorer.Client.provide_anomaly_feedback)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/ce.html#CostExplorer.Client.provide_anomaly_feedback)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#provide_anomaly_feedback)
         """
 
@@ -556,7 +558,7 @@ class CostExplorerClient(BaseClient):
         """
         Updates an existing cost anomaly monitor.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/ce.html#CostExplorer.Client.update_anomaly_monitor)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/ce.html#CostExplorer.Client.update_anomaly_monitor)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#update_anomaly_monitor)
         """
 
@@ -573,7 +575,7 @@ class CostExplorerClient(BaseClient):
         """
         Updates an existing cost anomaly monitor subscription.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/ce.html#CostExplorer.Client.update_anomaly_subscription)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/ce.html#CostExplorer.Client.update_anomaly_subscription)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#update_anomaly_subscription)
         """
 
@@ -583,11 +585,12 @@ class CostExplorerClient(BaseClient):
         CostCategoryArn: str,
         RuleVersion: Literal["CostCategoryExpression.v1"],
         Rules: List["CostCategoryRuleTypeDef"],
-        DefaultValue: str = None
+        DefaultValue: str = None,
+        SplitChargeRules: List["CostCategorySplitChargeRuleTypeDef"] = None
     ) -> UpdateCostCategoryDefinitionResponseTypeDef:
         """
         Updates an existing Cost Category.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.18/reference/services/ce.html#CostExplorer.Client.update_cost_category_definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.24/reference/services/ce.html#CostExplorer.Client.update_cost_category_definition)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#update_cost_category_definition)
         """
